Models
======

.. inheritance-diagram:: gmmvi.models.full_cov_gmm.FullCovGMM gmmvi.models.gmm.GMM gmmvi.models.diagonal_gmm.DiagonalGMM gmmvi.models.gmm_wrapper.GmmWrapper
   :parts: 1

.. automodule:: gmmvi.models.gmm
   :members:
   :undoc-members:

.. automodule:: gmmvi.models.full_cov_gmm
   :members:
   :undoc-members:

.. automodule:: gmmvi.models.diagonal_gmm
   :members:
   :undoc-members:

.. automodule:: gmmvi.models.gmm_wrapper
   :members:
   :undoc-members:
